;+
;
; Identifies which Compressed optical image to use for
; restoring a Low8 image.
;

FUNCTION sxt_low8_match, index

;
; INPUT PARAMETERS:
;	index = index of optical images, both Compressed and Low8
;
;  OUTPUT:
;	Array of subscripts, dimensioned 2 x n where n is the number 
;	of elements in the index array.  All non-optical (e.g., NaBan
;	or WdBan) entries in the array are set=-1.  The (0,n) values
;	are the subscripts of the Low8 images.  The (1,n) values
;	are the subscripts of the Compressed image to use.
;	If no valid Compressed image exists, (1,n) = -1.
;
; METHOD:
;	Finds closest Compressed image in time with same pointing,
;	size, and binning.  Must be within +/- 20 minutes of the
;	low8 image.
;
; HISTORY:
;	Written  June 28, 1994   Barry LaBonte
;	 2-11-2004 LWA  Editted for general application.
;
;-

; Get the needed information
compres = GT_COMP(index)
res = GT_RES(index)
days = index.gen.day
times = index.gen.time

; Make unique pointing identifiers
cent = index.sxt.corner_cmd(0) * LONG(1024) + index.sxt.corner_cmd(1)
shape = index.sxt.shape_sav(0) * LONG(1024) + index.sxt.shape_sav(1)
ucent = UNIQ( cent, SORT(cent) )
ushape = UNIQ( shape, SORT(shape) )

; Identify the different compressions
ssc = WHERE(gt_comp(index) eq  0 and gt_expmode(index) eq 0 and $
   (gt_filta(index) eq 2 or gt_filta(index) eq 5))
nc = N_ELEMENTS(ssc)
ssl = WHERE(gt_comp(index) eq 1 and (gt_filta(index) eq 2 or gt_filta(index) eq 5))
nl = N_ELEMENTS(ssl)

; Check for both compressions present, define output array
IF( nl LE 0 ) THEN RETURN,-1
outs = REPLICATE( LONG(-1), 2, n_elements(index) )
outs(0,ssl) = ssl
IF( nc LE 0 ) THEN RETURN, outs

; Walk through the Low 8 images
FOR i=0,nl-1 DO BEGIN
	good = WHERE( cent(ssl(i)) EQ cent(ssc) AND $
		shape(ssl(i)) EQ shape(ssc) AND     $
		res(ssl(i)) EQ res(ssc), count )
	IF( count GT 0 ) THEN BEGIN
		dt = (days(ssc(good)) - days(ssl(i))) * LONG(86400000) $
			+ times(ssc(good)) - times(ssl(i))
		mint = MIN( ABS(dt), ixmin )
; Solar rotation (disk center) between images must be < 1 FRpix.		
		if mint/60000. lt 16. then $
		   outs(1,ssl(i)) = ssc(good(ixmin))
	ENDIF
ENDFOR

RETURN, outs
END
